@@ -32,6 +32,6 @@ from ibm_watson_machine_learning.client import APIClient
 
 from .utils import is_python_2
 if is_python_2():
-    from ibm_watson_machine_learning.utils.log_util import get_logger
-    logger = get_logger('wml_client_initialization')
+    import logging
+    logger = logging.getLogger(__name__)
     logger.warning("Python 2 is not officially supported.")
