@@ -92,6 +92,7 @@ class Assets(WMLResource):
                     **return type**: dict\n
 
                 **Example**
+
                  >>> asset_details = client.data_assets.create(name="sample_asset",file_path="/path/to/file")
         """
         # quick support for COS credentials instead of local path
@@ -114,8 +115,8 @@ class Assets(WMLResource):
 
                       **type**: dict\n
 
-                      **Example**
-                           Example for data asset creation for files :
+                **Example**
+                    Example for data asset creation for files :
 
                             >>> metadata = {
                             >>>  client.data_assets.ConfigurationMetaNames.NAME: 'my data assets',
@@ -124,7 +125,7 @@ class Assets(WMLResource):
                             >>> }
                             >>> asset_details = client.data_assets.store(meta_props=metadata)
 
-                           Example of data asset creation using connection:
+                    Example of data asset creation using connection:
 
                             >>> metadata = {
                             >>>  client.data_assets.ConfigurationMetaNames.NAME: 'my data assets',
@@ -134,9 +135,9 @@ class Assets(WMLResource):
                             >>> }
                             >>> asset_details = client.data_assets.store(meta_props=metadata)
 
-                           Example for data asset creation with database sources type connection:
+                    Example for data asset creation with database sources type connection:
 
-                           >>> metadata = {
+                            >>> metadata = {
                             >>>  client.data_assets.ConfigurationMetaNames.NAME: 'my data assets',
                             >>>  client.data_assets.ConfigurationMetaNames.DESCRIPTION: 'sample description',
                             >>>  client.data_assets.ConfigurationMetaNames.CONNECTION_ID: '23eaf1ee-96a4-4651-b8fe-95d3dadfe',
@@ -365,6 +366,7 @@ class Assets(WMLResource):
             **Parameters**
 
             .. important::
+
                  #. **asset_uid**:  The Unique Id of the data asset to be downloaded\n
                     **type**: str\n
 
@@ -373,6 +375,8 @@ class Assets(WMLResource):
 
             **Output**
 
+            .. important::
+
                  **returns**: Path to the downloaded asset content\n
                  **return type**: str\n
 
