@@ -107,6 +107,7 @@ class Deployments(WMLResource):
                     **return type**: dict\n
 
                 **Example**
+
                  >>> meta_props = {
                  >>> wml_client.deployments.ConfigurationMetaNames.NAME: "SAMPLE DEPLOYMENT NAME",
                  >>> wml_client.deployments.ConfigurationMetaNames.ONLINE: {},
@@ -235,13 +236,18 @@ class Deployments(WMLResource):
 
                 status = deployment_details[u'entity'][u'status']['state']
 
+                notifications = []
+
                 with StatusLogger(status) as status_logger:
                     while True:
                         time.sleep(5)
                         deployment_details = self._client.deployments.get_details(deployment_uid)
                         #this is wrong , needs to update for ICP
                         if "system" in deployment_details:
-                            print("Note: " + deployment_details['system']['warnings'][0]['message'])
+                            notification = deployment_details['system']['warnings'][0]['message']
+                            if notification not in notifications:
+                                print("\nNote: " + notification)
+                                notifications.append(notification)
                         if self._ICP and not self._client.ICP_PLATFORM_SPACES:
                             scoringUrl = deployment_details.get(u'entity').get(u'asset').get('href').replace('https://wml-os-envoy:16600', predictionUrl)
                             deployment_details[u'entity'][u'asset']['href'] = scoringUrl
@@ -339,13 +345,13 @@ class Deployments(WMLResource):
             **Parameters**
             
             .. important::
-                #. **deployment_details**:  Metadata of the deployment\n
+                #. **deployment_details**:  Metadata of the deployment.\n
                    **type**: dict\n
             
             **Output**
             
             .. important::
-                **returns**: deployment href that is used to manage the deployment\n
+                **returns**: Deployment href that is used to manage the deployment.\n
                 **return type**: str
             
             **Example**
@@ -675,15 +681,22 @@ class Deployments(WMLResource):
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_download_url(deployment_details):
         """
-            Get deployment_download_url from deployment details.
+        Get deployment_download_url from deployment details.
 
-            :param deployment_details:  Created deployment details
-            :type deployment_details: dict
+        **Parameters**
 
-            :returns: deployment download URL that is used to get file deployment (for example: Core ML)
-            :rtype: {str_type}
+        .. important::
 
-            A way you might use me is:
+            #. **deployment_details**: Created deployment details.\n
+               **type**: dict\n
+
+        **Output**
+
+        .. important::
+            **returns**: Deployment download URL that is used to get file deployment (for example: Core ML).\n
+            **return type**: str\n
+
+        **Example**
 
             >>> deployment_url = client.deployments.get_download_url(deployment)
         """
@@ -702,17 +715,29 @@ class Deployments(WMLResource):
 
         return url
 
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def download(self, virtual_deployment_uid, filename=None):
         """
-            Downloads file deployment of specified deployment Id. Currently supported format is Core ML.
+        Downloads file deployment of specified deployment Id. Currently supported format is Core ML.
 
-            :param virtual_deployment_uid:  Unique Id of virtual deployment
-            :type virtual_deployment_uid: {str_type}
-            :param filename: filename of downloaded archive (optional)
-            :type filename: {str_type}
+        **Parameters**
 
-            :returns: path to downloaded file
-            :rtype: {str_type}
+        .. important::
+
+            #. **virtual_deployment_uid**:  Unique Id of virtual deployment.\n
+               **type**: str\n
+            #. **filename**: filename of downloaded archive (optional).\n
+               **type**: str\n
+
+        **Output**
+
+        .. important::
+            **returns**: Path to downloaded file.\n
+            **return type**: str\n
+
+        **Example**
+
+            >>> client.deployments.download(virtual_deployment_uid)
         """
         self._client._check_if_space_is_set()
         virtual_deployment_uid = str_type_conv(virtual_deployment_uid)
@@ -887,27 +912,27 @@ class Deployments(WMLResource):
 
     def list_jobs(self,limit=None):
         """
-           List the async deployment jobs. If limit is set to None there will be only first 50 records shown.
+        List the async deployment jobs. If limit is set to None there will be only first 50 records shown.
 
-           **Parameters**
+        **Parameters**
 
-           .. important::
-                #. **limit**:  limit number of fetched records\n
-                   **type**: int\n
+        .. important::
+            #. **limit**:  limit number of fetched records\n
+               **type**: int\n
 
-           **Output**
+        **Output**
 
-            .. important::
-                This method only prints the list of all async jobs in a table format.\n
+        .. important::
+
+            This method only prints the list of all async jobs in a table format.\n
                 **return type**: None\n
 
-            .. note::
-                * This method list only async deployment jobs created for WML deployment.
+        .. note::
+            * This method list only async deployment jobs created for WML deployment.
 
-           **Example**
-
-                 >>> client.deployments.list_jobs()
+        **Example**
 
+         >>> client.deployments.list_jobs()
         """
 
         details = self.get_job_details(limit=limit)
@@ -955,7 +980,7 @@ class Deployments(WMLResource):
                 
                 .. important::
 
-                    #. **deployment_uid**: Unqiue Id of deployment which  should be updated\n
+                    #. **deployment_uid**: Unique Id of deployment which  should be updated\n
                        **type**: str\n
                     #. **changes**:  elements which should be changed, where keys are ConfigurationMetaNames\n
                        **type**: dict\n
@@ -1276,7 +1301,7 @@ class Deployments(WMLResource):
 
            .. important::
 
-                #. **job_uid**: Unqiue Job ID (optional)\n
+                #. **job_uid**: Unique Job ID (optional)\n
                    **type**: str\n
                 #. **limit**:  limit number of fetched records (optional)\n
                    **type**: int\n
@@ -1411,29 +1436,29 @@ class Deployments(WMLResource):
         Cancels a deployment job that is currenlty running.  This method is also be used to delete metadata
         details of the completed or canceled jobs when hard_delete parameter is set to True.
 
-                **Parameters**
+        **Parameters**
 
-                .. important::
+        .. important::
 
-                    #. **job_uid**:  Unique Id of deployment job which  should be canceled\n
-                       **type**: str\n
+            #. **job_uid**:  Unique Id of deployment job which  should be canceled\n
+               **type**: str\n
 
-                    #. **hard_delete**: specify True or False.
-                                        True - To delete the completed or canceled job.
-                                        False - To cancel the currently running deployment job. Default value is False.
-                       **type**: Boolean\n
+            #. **hard_delete**: specify True or False.
+                                True - To delete the completed or canceled job.
+                                False - To cancel the currently running deployment job. Default value is False.
+               **type**: Boolean\n
 
 
-                **Output**
+        **Output**
 
-                .. important::
+        .. important::
 
-                    **returns**: status ("SUCCESS" or "FAILED")\n
-                    **return type**: str\n
+            **returns**: status ("SUCCESS" or "FAILED")\n
+            **return type**: str\n
 
-                **Example**
+        **Example**
 
-                 >>> client.deployments.delete_job(job_uid)
+         >>> client.deployments.delete_job(job_uid)
 
         """
 
