@@ -17,11 +17,12 @@ from typing import List, Union
 
 from ibm_watson_machine_learning.preprocessing import DataJoinGraph
 from ibm_watson_machine_learning.utils.autoai.enums import (
-    TShirtSize, ClassificationAlgorithms, RegressionAlgorithms, PredictionType, Metrics, Transformers,
-    DataConnectionTypes, PipelineTypes, PositiveLabelClass)
-from ibm_watson_machine_learning.utils.autoai.errors import LocalInstanceButRemoteParameter, MissingPositiveLabel
-from ibm_watson_machine_learning.utils.autoai.utils import check_dependencies_versions,\
-    validate_additional_params_for_optimizer
+    TShirtSize, ClassificationAlgorithms, RegressionAlgorithms, ForecastingAlgorithms, PredictionType, Metrics,\
+    Transformers, DataConnectionTypes, PipelineTypes, PositiveLabelClass)
+from ibm_watson_machine_learning.utils.autoai.errors import LocalInstanceButRemoteParameter, MissingPositiveLabel, \
+    NonForecastPredictionColumnMissing, ForecastPredictionColumnsMissing, ForecastingCannotBeRunAsLocalScenario
+from ibm_watson_machine_learning.utils.autoai.utils import check_dependencies_versions, \
+    validate_additional_params_for_optimizer, is_list_composed_from_enum
 from ibm_watson_machine_learning.workspace import WorkSpace
 from .engines import WMLEngine
 from .optimizers import LocalAutoPipelines, RemoteAutoPipelines
@@ -68,6 +69,7 @@ class AutoAI(BaseExperiment):
     # note: initialization of AutoAI enums as class properties
     ClassificationAlgorithms = ClassificationAlgorithms
     RegressionAlgorithms = RegressionAlgorithms
+    _ForecastingAlgorithms = ForecastingAlgorithms
     TShirtSize = TShirtSize
     PredictionType = PredictionType
     Metrics = Metrics
@@ -136,13 +138,22 @@ class AutoAI(BaseExperiment):
                   name: str,
                   *,
                   prediction_type: 'PredictionType',
-                  prediction_column: str,
+                  prediction_column: str = None,
+                  #prediction_columns: List[str] = None,
+                  #timestamp_column_name: str = None,
                   scoring: 'Metrics',
                   desc: str = None,
-                  test_size: float = 0.1,
+                  test_size: float = None, # deprecated
+                  holdout_size: float = 0.1,
                   max_number_of_estimators: int = 2,
                   train_sample_rows_test_size: float = None,
-                  daub_include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']] = None,
+                  include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms',
+                                                      'ForecastingAlgorithms']] = None,
+                  daub_include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']] = None, # deprecated
+                  #backtest_num: int = None,
+                  #lookback_window: int = None,
+                  #forecast_window: int = None,
+                  #backtest_gap_length: int = None,
                   cognito_transform_names: List['Transformers'] = None,
                   data_join_graph: 'DataJoinGraph' = None,
                   csv_separator: Union[List[str], str] = ',',
@@ -163,8 +174,8 @@ class AutoAI(BaseExperiment):
         prediction_type: PredictionType, required
             Type of the prediction.
 
-        prediction_column: str, required
-            name of the target/label column
+        prediction_column: str, required for multiclass, binary and regression prediction types
+            Name of the target/label column
 
         scoring: Metrics, required
             Type of the metric to optimize with.
@@ -172,7 +183,10 @@ class AutoAI(BaseExperiment):
         desc: str, optional
             Description
 
-        test_size: float, optional
+        test_size: deprecated
+            Use `holdout_size` instead.
+
+        holdout_size: float, optional
             Percentage of the entire dataset to leave as a holdout. Default 0.1
 
         max_number_of_estimators: int, optional
@@ -184,9 +198,12 @@ class AutoAI(BaseExperiment):
         train_sample_rows_test_size: float, optional
             Training data sampling percentage
 
-        daub_include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']], optional
+        daub_include_only_estimators: deprecated
+            Use `include_only_estimators` instead.
+
+        include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms', 'ForecastingAlgorithms']], optional
             List of estimators to include in computation process.
-            See: AutoAI.ClassificationAlgorithms or AutoAI.RegressionAlgorithms
+            See: AutoAI.ClassificationAlgorithms, AutoAI.RegressionAlgorithms or AutoAI.ForecastingAlgorithms
 
         cognito_transform_names: List['Transformers'], optional
             List of transformers to include in feature enginnering computation process.
@@ -237,11 +254,11 @@ class AutoAI(BaseExperiment):
         >>>        prediction_column="y",
         >>>        scoring=AutoAI.Metrics.ROC_AUC_SCORE,
         >>>        desc="Some description.",
-        >>>        test_size=0.1,
+        >>>        holdout_size=0.1,
         >>>        max_num_daub_ensembles=1,
         >>>        cognito_transform_names=[AutoAI.Transformers.SUM,AutoAI.Transformers.MAX],
         >>>        train_sample_rows_test_size=1,
-        >>>        daub_include_only_estimators=[AutoAI.ClassificationAlgorithms.LGBM, AutoAI.ClassificationAlgorithms.XGB],
+        >>>        include_only_estimators=[AutoAI.ClassificationAlgorithms.LGBM, AutoAI.ClassificationAlgorithms.XGB],
         >>>        t_shirt_size=AutoAI.TShirtSize.L
         >>>    )
         >>>
@@ -253,6 +270,98 @@ class AutoAI(BaseExperiment):
         >>>        desc="Some description.",
         >>>    )
         """
+        # Hidden documentation - to be recovered when TS will be officially supported:
+
+        # prediction_columns: List[str], required for forecasting prediction type
+        #     Names of the target/label columns.
+
+        # timestamp_column_name: str, optional, used only for forecasting prediction type
+        #     Name of timestamp column for time series forecasting.
+
+        # backtest_num: int, optional
+        #     Used for forecasting prediction type. Configure number of backtests. Default value: 4
+        #     Value from range [0, 20]
+
+        # lookback_window: int, optional
+        #     Used for forecasting prediction type. Configure length of lookback window. Default value: 10
+        #     If set to -1 lookback window will be auto-detected
+
+        # forecast_window: int, optional
+        #     Used for forecasting prediction type. Configure length of forecast window. Default value: 1
+        #     Value from range [1, 60]
+
+        # backtest_gap_length: int, optional
+        #     Used for forecasting prediction type. Configure gap between backtests. Default value: 0
+        #     Value from range [0, data length / 4]
+
+        ## To be removed when TS enabled oficially:
+        if prediction_type == PredictionType._FORECASTING \
+            and ('ts_enabled' not in self._workspace.wml_client.wml_credentials
+                 or not self._workspace.wml_client.wml_credentials['ts_enabled']):
+            raise NotImplementedError()
+
+        prediction_columns = kwargs.get('prediction_columns')
+        timestamp_column_name = kwargs.get('timestamp_column_name')
+
+        backtest_num = kwargs.get('backtest_num')
+        lookback_window = kwargs.get('lookback_window')
+        forecast_window = kwargs.get('forecast_window')
+        backtest_gap_length = kwargs.get('backtest_gap_length')
+
+        try:
+            del kwargs['prediction_columns']
+        except:
+            pass
+        try:
+            del kwargs['timestamp_column_name']
+        except:
+            pass
+
+        try:
+            del kwargs['backtest_num']
+        except:
+            pass
+        try:
+            del kwargs['lookback_window']
+        except:
+            pass
+        try:
+            del kwargs['forecast_window']
+        except:
+            pass
+        try:
+            del kwargs['backtest_gap_length']
+        except:
+            pass
+
+        ## - end of section
+
+        if prediction_type == PredictionType._FORECASTING:
+            if prediction_column is not None or prediction_columns is None:
+                raise ForecastPredictionColumnsMissing()
+        else:
+            if prediction_column is None or prediction_columns is not None:
+                raise NonForecastPredictionColumnMissing(prediction_type)
+
+        if test_size:
+            print('Note: Using `test_size` is deprecated. Use `holdout_size` instead.')
+            if not holdout_size:
+                holdout_size = test_size
+            test_size = None
+
+        if daub_include_only_estimators:
+            print('Note: Using `daub_include_only_estimators` is deprecated. Use `include_only_estimators` instead.')
+            if not include_only_estimators:
+                include_only_estimators = daub_include_only_estimators
+            daub_include_only_estimators = None
+
+        for (sequence, enum_class) in (
+                (daub_include_only_estimators,
+                 AutoAI.RegressionAlgorithms if prediction_type == AutoAI.PredictionType.REGRESSION
+                    else AutoAI.ClassificationAlgorithms),
+                (cognito_transform_names, AutoAI.Transformers)):
+            is_list_composed_from_enum(sequence, enum_class)
+
         if data_join_graph:
             data_join_graph.problem_type = prediction_type
             data_join_graph.target_column = prediction_column
@@ -269,6 +378,9 @@ class AutoAI(BaseExperiment):
                        "\"t_shirt_size\" parameter is only applicable to the RemoteOptimizer instance."
             )
         elif self._workspace is None:
+            if prediction_type == PredictionType._FORECASTING:
+                raise ForecastingCannotBeRunAsLocalScenario()
+
             reduced_kwargs = copy.copy(kwargs)
 
             for n in ['_force_local_scenario']:
@@ -283,10 +395,10 @@ class AutoAI(BaseExperiment):
                 prediction_column=prediction_column,
                 scoring=scoring,
                 desc=desc,
-                test_size=test_size,
+                holdout_size=holdout_size,
                 max_num_daub_ensembles=max_number_of_estimators,
                 train_sample_rows_test_size=train_sample_rows_test_size,
-                daub_include_only_estimators=daub_include_only_estimators,
+                include_only_estimators=include_only_estimators,
                 cognito_transform_names=cognito_transform_names,
                 positive_label=positive_label,
                 _force_local_scenario=kwargs.get('_force_local_scenario', False),
@@ -311,15 +423,21 @@ class AutoAI(BaseExperiment):
                 name=name,
                 prediction_type=prediction_type,
                 prediction_column=prediction_column,
+                prediction_columns=prediction_columns,
+                timestamp_column_name=timestamp_column_name,
                 scoring=scoring,
                 desc=desc,
-                test_size=test_size,
+                holdout_size=holdout_size,
                 max_num_daub_ensembles=max_number_of_estimators,
                 t_shirt_size=self._workspace.restrict_pod_size(t_shirt_size=kwargs.get(
                     't_shirt_size', TShirtSize.M if self._workspace.wml_client.ICP else TShirtSize.L)
                 ),
                 train_sample_rows_test_size=train_sample_rows_test_size,
-                daub_include_only_estimators=daub_include_only_estimators,
+                include_only_estimators=include_only_estimators,
+                backtest_num=backtest_num,
+                lookback_window=lookback_window,
+                forecast_window=forecast_window,
+                backtest_gap_length=backtest_gap_length,
                 cognito_transform_names=cognito_transform_names,
                 data_join_graph=data_join_graph,
                 drop_duplicates=drop_duplicates,
