@@ -22,7 +22,7 @@ import warnings
 from ibm_watson_machine_learning.utils.autoai.enums import (
     PredictionType, RegressionAlgorithms, ClassificationAlgorithms, RunStateTypes)
 from ibm_watson_machine_learning.utils.autoai.errors import PipelineNotLoaded, FitNeeded, InvalidPredictionType, \
-    AutoAIComputeError
+    AutoAIComputeError, ForecastingUnsupportedOperation, NoAvailableMetrics
 from ibm_watson_machine_learning.wml_client_error import ApiRequestFailure
 from ibm_watson_machine_learning.utils.autoai.progress_bar import ProgressBar
 from ibm_watson_machine_learning.utils.autoai.utils import (
@@ -87,16 +87,12 @@ class WMLEngine(BaseEngine):
                             'encoding': self._auto_pipelines_parameters.get('encoding'),
                             'drop_duplicates': self._auto_pipelines_parameters.get('drop_duplicates'),
                             'optimization': {
-                                'learning_type': self._auto_pipelines_parameters.get('prediction_type'),
-                                'label': self._auto_pipelines_parameters.get('prediction_column'),
+                                'learning_type': 'timeseries' if self._auto_pipelines_parameters.get('prediction_type') == PredictionType._FORECASTING else self._auto_pipelines_parameters.get('prediction_type'),
                                 'max_num_daub_ensembles': self._auto_pipelines_parameters.get('max_num_daub_ensembles'),
                                 'cognito_transform_names':
                                     self._auto_pipelines_parameters.get('cognito_transform_names'),
-                                'scorer_for_ranking': self._auto_pipelines_parameters.get('scoring'),
-                                'compute_pipeline_notebooks_flag': self._auto_pipelines_parameters.get('notebooks',
-                                                                                                       False),
                                 'run_cognito_flag': True,
-                                'holdout_param': self._auto_pipelines_parameters.get('test_size')
+                                'holdout_param': self._auto_pipelines_parameters.get('holdout_size')
                             }
                         },
                         'runtime_ref': 'autoai',
@@ -105,7 +101,7 @@ class WMLEngine(BaseEngine):
                 }],
                 'runtimes': [{
                     'id': 'autoai',
-                    'name': 'auto_ai.kb',
+                    'name': 'auto_ai.kb' if self._auto_pipelines_parameters.get('prediction_type') != PredictionType._FORECASTING else 'auto_ai.ts',
                     'app_data': {
                         'wml_data': {
                             'hardware_spec': {}
@@ -116,6 +112,40 @@ class WMLEngine(BaseEngine):
             }
         }
 
+        if self._auto_pipelines_parameters.get('prediction_type') == PredictionType._FORECASTING:
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                'target_columns'] = self._auto_pipelines_parameters['prediction_columns']
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                'timestamp_column'] = self._auto_pipelines_parameters['timestamp_column_name']
+            if self._auto_pipelines_parameters['backtest_num']:
+                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                    'num_backtest'] = self._auto_pipelines_parameters['backtest_num']
+            if self._auto_pipelines_parameters['lookback_window']:
+                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                    'lookback_window'] = self._auto_pipelines_parameters['lookback_window']
+            if self._auto_pipelines_parameters['forecast_window']:
+                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                    'prediction_horizon'] = self._auto_pipelines_parameters['forecast_window']
+            if self._auto_pipelines_parameters['backtest_gap_length'] != None:
+                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                    'gap_len'] = self._auto_pipelines_parameters['backtest_gap_length']
+        else:
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                'label'] = self._auto_pipelines_parameters['prediction_column']
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                'compute_pipeline_notebooks_flag'] = self._auto_pipelines_parameters.get('notebooks', False)
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                'scorer_for_ranking'] = self._auto_pipelines_parameters.get('scoring')
+
         if self._20_class_limit_removal_test:
             self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT]['pipelines'][0]['nodes'][0]['parameters'].update({
                 'one_vs_all_file': True
@@ -157,13 +187,13 @@ class WMLEngine(BaseEngine):
                 'pipelines'][0]['nodes'][0]['parameters']['optimization'][
                 'daub_adaptive_subsampling_max_mem_usage'] = 25e9
 
-        if self._auto_pipelines_parameters.get('daub_include_only_estimators') is not None:
+        if self._auto_pipelines_parameters.get('include_only_estimators') is not None:
             # note: transform values from Enum
             try:
                 self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                     'pipelines'][0]['nodes'][0]['parameters']['optimization'][
                     'daub_include_only_estimators'] = [
-                    algorithm.value for algorithm in self._auto_pipelines_parameters.get('daub_include_only_estimators')
+                    algorithm.value for algorithm in self._auto_pipelines_parameters.get('include_only_estimators')
                 ]
             # note: if user pass strings instead of enums
             except AttributeError:
@@ -543,7 +573,6 @@ class WMLEngine(BaseEngine):
         pipeline_parameters = {
             "composition_steps": [],
             "pipeline_nodes": [],
-            "features_importance": None,
         }
 
         # note: retrieve all additional pipeline evaluation information
@@ -553,7 +582,12 @@ class WMLEngine(BaseEngine):
                 pipeline_parameters['composition_steps'] = pipeline['context']['intermediate_model'][
                     'composition_steps']
                 pipeline_parameters['pipeline_nodes'] = pipeline['context']['intermediate_model']['pipeline_nodes']
-                pipeline_parameters['ml_metrics'] = self._get_metrics(pipeline)
+                if 'timeseries' not in pipeline['context']:
+                    pipeline_parameters['ml_metrics'] = self._get_metrics(pipeline)
+                else:
+                    if not 'ts_metrics' in pipeline_parameters:
+                        pipeline_parameters['ts_metrics'] = {}
+                    pipeline_parameters['ts_metrics'].update(self._get_metrics(pipeline))
 
                 if (self._auto_pipelines_parameters['prediction_type'] == 'binary'
                         or (self._auto_pipelines_parameters['prediction_type'] == 'classification'
@@ -578,6 +612,15 @@ class WMLEngine(BaseEngine):
                 elif self._auto_pipelines_parameters['prediction_type'] == 'regression':
                     pipeline_parameters['features_importance'] = self._get_features_importance(pipeline)
 
+                elif self._auto_pipelines_parameters['prediction_type'] == 'forecasting':
+                    data = WMLEngine._get_data_from_property_or_file('daub_status', pipeline['context']['timeseries'],
+                                                                     run_params['entity']['results_reference'],
+                                                                     [{}, {}])
+                    if 'visualization' in data:
+                        if 'visualization' not in pipeline_parameters:
+                            pipeline_parameters['visualization'] = {}
+                        pipeline_parameters['visualization'].update(data['visualization'])
+
                 else:
                     raise InvalidPredictionType(self._auto_pipelines_parameters['prediction_type'],
                                                 reason="Prediction type not recognized.")
@@ -589,7 +632,17 @@ class WMLEngine(BaseEngine):
     @staticmethod
     def _get_metrics(pipeline_details: Dict) -> 'DataFrame':
         """Retrieve evaluation metrics data from particular pipeline details."""
-        data = pipeline_details['ml_metrics']
+        is_ml_metrics = 'ml_metrics' in pipeline_details
+        is_ts_metrics = 'ts_metrics' in pipeline_details
+
+        if not is_ml_metrics and not is_ts_metrics:
+            raise NoAvailableMetrics()
+
+        if is_ml_metrics:
+            data = pipeline_details['ml_metrics']
+        elif is_ts_metrics:
+            data = pipeline_details['ts_metrics']
+
         columns = [field for field in data.keys()]
         values = [[value for value in data.values()]]
 
@@ -719,6 +772,9 @@ class WMLEngine(BaseEngine):
 
         run_params = self._wml_client.training.get_details(training_uid=self._current_run_id)
 
+        if 'timeseries' in run_params['entity']['status']['metrics'][0]['context']:
+            raise ForecastingUnsupportedOperation()
+
         try:
             pipelines: Dict[str, 'Pipeline'] = fetch_pipelines(
                 run_params=run_params,
