@@ -26,7 +26,8 @@ from ibm_watson_machine_learning.utils.autoai.enums import (
     RunStateTypes, PipelineTypes, TShirtSize, ClassificationAlgorithms, RegressionAlgorithms, DataConnectionTypes)
 from ibm_watson_machine_learning.utils.autoai.errors import (
     FitNotCompleted, MissingDataPreprocessingStep, WrongDataJoinGraphNodeName, DataSourceSizeNotSupported,
-    TrainingDataSourceIsNotFile, NoneDataConnection, PipelineNotLoaded, OBMForNFSIsNotSupported)
+    TrainingDataSourceIsNotFile, NoneDataConnection, PipelineNotLoaded, OBMForNFSIsNotSupported,
+    ForecastingUnsupportedOperation)
 from ibm_watson_machine_learning.utils.autoai.utils import try_import_lale
 from ibm_watson_machine_learning.utils.autoai.wsd_ui import (
     save_computed_pipelines_for_ui, save_experiment_for_ui, save_metadata_for_ui)
@@ -65,7 +66,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
     desc: str, optional
         Description
 
-    test_size: float, optional
+    holdout_size: float, optional
         Percentage of the entire dataset to leave as a holdout. Default 0.1
 
     max_num_daub_ensembles: int, optional
@@ -77,7 +78,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
     train_sample_rows_test_size: float, optional
         Training data sampling percentage
 
-    daub_include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']], optional
+    include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']], optional
         List of estimators to include in computation process.
 
     cognito_transform_names: List['Transformers'], optional
@@ -116,14 +117,20 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  name: str,
                  prediction_type: 'PredictionType',
                  prediction_column: str,
+                 prediction_columns: List[str],
+                 timestamp_column_name: str,
                  scoring: 'Metrics',
                  engine: 'WMLEngine',
                  desc: str = None,
-                 test_size: float = 0.1,
+                 holdout_size: float = 0.1,
                  max_num_daub_ensembles: int = 1,
                  t_shirt_size: 'TShirtSize' = TShirtSize.M,
                  train_sample_rows_test_size: float = None,
-                 daub_include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']] = None,
+                 include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']] = None,
+                 backtest_num: int = None,
+                 lookback_window: int = None,
+                 forecast_window: int = None,
+                 backtest_gap_length: int = None,
                  cognito_transform_names: List['Transformers'] = None,
                  data_join_graph: 'DataJoinGraph' = None,
                  csv_separator: Union[List[str], str] = ',',
@@ -141,12 +148,18 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             'desc': desc if desc else '',
             'prediction_type': prediction_type,
             'prediction_column': prediction_column,
+            'prediction_columns': prediction_columns,
+            'timestamp_column_name': timestamp_column_name,
             'scoring': scoring,
-            'test_size': test_size,
+            'holdout_size': holdout_size,
             'max_num_daub_ensembles': max_num_daub_ensembles,
             't_shirt_size': t_shirt_size,
             'train_sample_rows_test_size': train_sample_rows_test_size,
-            'daub_include_only_estimators': daub_include_only_estimators,
+            'include_only_estimators': include_only_estimators,
+            'backtest_num': backtest_num,
+            'lookback_window': lookback_window,
+            'forecast_window': forecast_window,
+            'backtest_gap_length': backtest_gap_length,
             'cognito_transform_names': cognito_transform_names,
             'data_join_graph': data_join_graph or False,
             'csv_separator': csv_separator,
@@ -192,16 +205,16 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                 'prediction_type': 'classification',
                 'prediction_column': 'y',
                 'scoring': 'roc_auc',
-                'test_size': 0.1,
+                'holdout_size': 0.1,
                 'max_num_daub_ensembles': 1,
                 't_shirt_size': 'm',
                 'train_sample_rows_test_size': 0.8,
-                'daub_include_only_estimators': ["ExtraTreesClassifierEstimator",
-                                                "GradientBoostingClassifierEstimator",
-                                                "LGBMClassifierEstimator",
-                                                "LogisticRegressionEstimator",
-                                                "RandomForestClassifierEstimator",
-                                                "XGBClassifierEstimator"]
+                'include_only_estimators': ["ExtraTreesClassifierEstimator",
+                                            "GradientBoostingClassifierEstimator",
+                                            "LGBMClassifierEstimator",
+                                            "LogisticRegressionEstimator",
+                                            "RandomForestClassifierEstimator",
+                                            "XGBClassifierEstimator"]
             }
         """
         _params = self._engine.get_params().copy()
@@ -530,6 +543,8 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             else:
                 pipeline_model = self._engine.get_pipeline(pipeline_name=pipeline_name, persist=persist)
 
+        except ForecastingUnsupportedOperation as e:
+            raise e
         except Exception as e:
             raise PipelineNotLoaded(pipeline_name if pipeline_name is not None else 'best pipeline',
                                     reason=f"Pipeline with such a name probably does not exist. "
@@ -656,12 +671,8 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         if optimizer_parameters['data_join_graph']:
             details = self._engine._wml_client.training.get_details(
                 training_uid=self._engine._current_run_id)
-            if self.params['data_join_only']:
-                path = f"{details['entity']['results_reference']['location']['path']}/{self._engine._current_run_id}"
-            else:
-                path = details['entity']['status']['metrics'][0]['context']['intermediate_model'][
-                    'location']['model'].split('/data/kb/')[0]
-            path = f"{path}/data/obm/features/part"
+
+            path = f"{details['entity']['results_reference']['location']['path']}/{self._engine._current_run_id}/data/obm/features/part"
 
             results_connection = DataConnection._from_dict(_dict=details['entity']['results_reference'])
             results_connection.auto_pipeline_params = deepcopy(optimizer_parameters)
