@@ -144,7 +144,7 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
                 'prediction_type': 'classification',
                 'prediction_column': 'y',
                 'scoring': 'roc_auc',
-                'test_size': 0.1,
+                'holdout_size': 0.1,
                 'max_num_daub_ensembles': 1
             }
         """
@@ -196,12 +196,14 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
                 'name': name,
                 'desc': description,
                 'prediction_type': kb_parameters['learning_type'],
-                'prediction_column': kb_parameters['label'],
+                'prediction_column': kb_parameters.get('label'),
+                'prediction_columns': kb_parameters.get('target_columns'),
+                'timestamp_column_name': kb_parameters.get('timestamp_column'),
                 'scoring': kb_parameters['scorer_for_ranking'],
-                'test_size': kb_parameters['holdout_param'],
+                'holdout_size': kb_parameters['holdout_param'],
                 'max_num_daub_ensembles': kb_parameters['max_num_daub_ensembles'],
                 't_shirt_size': kb_wml_data['hardware_spec']['id'],
-                'daub_include_only_estimators': kb_parameters.get('daub_include_only_estimators'),
+                'include_only_estimators': kb_parameters.get('include_only_estimators'),
                 'cognito_transform_names': kb_parameters.get('cognito_transform_names'),
                 'train_sample_rows_test_size': kb_parameters.get('train_sample_rows_test_size'),
                 'csv_separator': csv_separator,
@@ -217,6 +219,8 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
                 'desc': description,
                 'prediction_type': None,
                 'prediction_column': None,
+                'prediction_columns': None,
+                'timestamp_column_name': None,
                 'scoring': None,
                 'data_join_only': True
             }
