@@ -14,4 +14,5 @@
 
 from ibm_watson_machine_learning.helpers.helpers import *
 from ibm_watson_machine_learning.helpers.connections import (
-    DataConnection, S3Connection, S3Location, FSLocation, DSLocation, CP4DAssetLocation, WMLSAssetLocation, WSDAssetLocation)
+    DataConnection, S3Connection, S3Location, FSLocation, AssetLocation, CP4DAssetLocation, WMLSAssetLocation,
+    WSDAssetLocation, NFSLocation, NFSConnection)
