@@ -377,14 +377,14 @@ class DataConnection(BaseDataConnection):
                 x, x_holdout, y, y_holdout = train_test_split(
                     data.drop([self.auto_pipeline_params['prediction_column']], axis=1),
                     data[self.auto_pipeline_params['prediction_column']].values,
-                    test_size=self.auto_pipeline_params['test_size'],
+                    test_size=self.auto_pipeline_params['holdout_size'],
                     random_state=33,
                     stratify=data[self.auto_pipeline_params['prediction_column']].values)
             else:
                 x, x_holdout, y, y_holdout = train_test_split(
                     data.drop([self.auto_pipeline_params['prediction_column']], axis=1),
                     data[self.auto_pipeline_params['prediction_column']].values,
-                    test_size=self.auto_pipeline_params['test_size'],
+                    test_size=self.auto_pipeline_params['holdout_size'],
                     random_state=33)
 
             data_train = DataFrame(data=x, columns=data.columns.tolist())
