@@ -49,7 +49,7 @@ class HwSpec(WMLResource):
 
             .. important::
                 **returns**: Metadata of the hardware specifications\n
-                **return type**: dict\n of hw_spec\n
+                **return type**: dict\n
 
             **Example**
 
@@ -179,7 +179,6 @@ class HwSpec(WMLResource):
 
                    #. **asset_details**:  Metadata of the hardware specifications \n
                       **type**: dict\n
-                      **type**: dict\n
 
                 **Output**
 
@@ -208,7 +207,6 @@ class HwSpec(WMLResource):
 
                    #. **asset_details**:  Metadata of the hardware specifications \n
                       **type**: dict\n
-                      **type**: dict\n
 
                 **Output**
 
