@@ -168,6 +168,7 @@ class Pipelines(WMLResource):
             >>> pipeline_url = client.pipelines.get_href(pipeline_details)
 
         """
+        WMLResource._chk_and_block_create_update_for_python36(self)
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
 
@@ -315,6 +316,7 @@ class Pipelines(WMLResource):
             >>> client.pipelines.create_revision(pipeline_uid)
 
         """
+        WMLResource._chk_and_block_create_update_for_python36(self)
         pipeline_uid = str_type_conv(pipeline_uid)
         Pipelines._validate_type(pipeline_uid, u'pipeline_uid', STR_TYPE, False)
 
@@ -355,6 +357,7 @@ class Pipelines(WMLResource):
                  >>> pipeline_details = client.pipelines.update(pipeline_uid, changes=metadata)
 
         """
+        WMLResource._chk_and_block_create_update_for_python36(self)
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
         if self._client.WSD:
@@ -488,7 +491,7 @@ class Pipelines(WMLResource):
         Pipelines._validate_type(rev_uid, u'rev_uid', int, True)
         if not self._client.ICP_30 and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35:
             raise WMLClientError(
-                'Not supported. Revisions APIs are supported only for WML Cloud Pack for Data 3.0 and above.')
+                'Not supported. Revisions APIs are supported only for IBM Cloud Pak® for Data for Data 3.0 and above.')
         else:
             url = self._href_definitions.get_pipeline_href(pipeline_uid)
         return self._get_with_or_without_limit(url, limit=None, op_name="pipeline",
