@@ -407,47 +407,47 @@ class Repository(WMLResource):
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def clone(self, artifact_id, space_id=None, action="copy", rev_id=None):
-        """
-            Creates a new resource(models, runtimes, libraries, experiments, functions, pipelines) identical with the model either in the same space or in a new space. All dependent assets will be cloned too.
-
-            **Parameters**
-
-            .. important::
-                #. **model_id**:  Guid of the artifact to be cloned:\n
-
-                   **type**: str\n
-
-                #. **space_id**: Guid of the space to which the model needs to be cloned. (optional)
-
-                   **type**: str\n
-
-                #. **action**: Action specifying "copy" or "move". (optional)
-
-                   **type**: str\n
-
-                #. **rev_id**: Revision ID of the artifact. (optional)
-
-                   **type**: str\n
-
-            **Output**
-
-            .. important::
-
-                    **returns**: Metadata of the model cloned.\n
-                    **return type**: dict\n
-
-            **Example**
-
-             >>> client.repository.clone(artifact_id=artifact_id,space_id=space_uid,action="copy")
-
-            .. note::
-                * If revision id is not specified, all revisions of the artifact are cloned\n
-
-                * Default value of the parameter action is copy\n
-
-                * Space guid is mandatory for move action\n
-
-            """
+        # """ it is not supported in v4ga
+        #     Creates a new resource(models, runtimes, libraries, experiments, functions, pipelines) identical with the model either in the same space or in a new space. All dependent assets will be cloned too.
+        #
+        #     **Parameters**
+        #
+        #     .. important::
+        #         #. **model_id**:  Guid of the artifact to be cloned:\n
+        #
+        #            **type**: str\n
+        #
+        #         #. **space_id**: Guid of the space to which the model needs to be cloned. (optional)
+        #
+        #            **type**: str\n
+        #
+        #         #. **action**: Action specifying "copy" or "move". (optional)
+        #
+        #            **type**: str\n
+        #
+        #         #. **rev_id**: Revision ID of the artifact. (optional)
+        #
+        #            **type**: str\n
+        #
+        #     **Output**
+        #
+        #     .. important::
+        #
+        #             **returns**: Metadata of the model cloned.\n
+        #             **return type**: dict\n
+        #
+        #     **Example**
+        #
+        #      >>> client.repository.clone(artifact_id=artifact_id,space_id=space_uid,action="copy")
+        #
+        #     .. note::
+        #         * If revision id is not specified, all revisions of the artifact are cloned\n
+        #
+        #         * Default value of the parameter action is copy\n
+        #
+        #         * Space guid is mandatory for move action\n
+        #
+        #     """
         if self._client.WSD or self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError('Cloning is not supported.')
         artifact = str_type_conv(artifact_id)
@@ -889,6 +889,7 @@ class Repository(WMLResource):
                **Example**
 
                 >>> client.repository.download(model_uid, 'my_model.tar.gz')
+                >>> client.repository.download(model_uid, 'my_model.json') # if original model was saved as json, works only for xgboost 1.3
         """
         self._validate_type(artifact_uid, 'artifact_uid', STR_TYPE, True)
         self._validate_type(filename, 'filename', STR_TYPE, True)
