@@ -111,7 +111,7 @@ class TestAutoAIRemote(unittest.TestCase):
         space_cleanup(self.wml_client,
                       get_space_id(self.wml_client, self.space_name,
                                    cos_resource_instance_id=self.cos_resource_instance_id),
-                      days_old=2)
+                      days_old=7)
         TestAutoAIRemote.space_id = get_space_id(self.wml_client, self.space_name,
                                      cos_resource_instance_id=self.cos_resource_instance_id)
         if self.wml_client.ICP:
@@ -375,7 +375,7 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_25_delete_deployment(self):
         print("Delete current deployment: {}".format(self.service.deployment_id))
         self.service.delete()
-        self.wml_client.set.default_space(self.space_id) if is_cp4d() else None
+        self.wml_client.set.default_space(self.space_id) if not self.wml_client.default_space_id else None
         self.wml_client.repository.delete(self.service.asset_id)
         self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
         self.assertEqual(self.service.id, None, msg="Deployment ID deleted incorrectly")
@@ -418,6 +418,7 @@ class TestAutoAIRemote(unittest.TestCase):
             payload=self.train_data.drop(columns=[self.prediction_column]),
             background_mode=False)
         print(scoring_params)
+        print(self.service_batch.get_job_result(scoring_params['metadata']['id']))
         self.assertIsNotNone(scoring_params)
         self.assertIn('predictions', str(scoring_params).lower())
 
@@ -434,7 +435,7 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_35_delete_deployment_batch(self):
         print("Delete current deployment: {}".format(self.service_batch.deployment_id))
         self.service_batch.delete()
-        self.wml_client.set.default_space(self.space_id) if is_cp4d() else None
+        self.wml_client.set.default_space(self.space_id) if not self.wml_client.default_space_id else None
         self.wml_client.repository.delete(self.service_batch.asset_id)
         self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
         self.assertEqual(self.service_batch.id, None, msg="Deployment ID deleted incorrectly")
