@@ -472,7 +472,7 @@ class Training(WMLResource):
             state = status[u'state']
 
             with StatusLogger(state) as status_logger:
-                while state not in ['error', 'completed', 'canceled']:
+                while state not in ['error', 'completed', 'canceled', 'failed']:
                     time.sleep(5)
                     state = self.get_status(trained_model_guid)['state']
                     status_logger.log_state(state)
