@@ -17,6 +17,7 @@ from enum import Enum
 __all__ = [
     "ClassificationAlgorithms",
     "RegressionAlgorithms",
+    "ForecastingAlgorithms",
     "PredictionType",
     "Metrics",
     "Transformers",
@@ -54,6 +55,17 @@ class RegressionAlgorithms(Enum):
     DT = "DecisionTreeRegressorEstimator"
 
 
+class ForecastingAlgorithms(Enum):
+    """Forecasting algorithms that AutoAI could use."""
+    LR = "LinearRegression"
+    ENSEMBLER = "Ensembler"
+    ARIMA = "ARIMA"
+    HW = "HoltWinters"
+    BATS = "BATS"
+    RF = "RandomForest"
+    SVM = "SVM"
+
+
 class PredictionType:
     """
         Supported types of learning.
@@ -62,6 +74,7 @@ class PredictionType:
     BINARY = "binary"
     MULTICLASS = "multiclass"
     REGRESSION = "regression"
+    _FORECASTING = "forecasting"
 
 
 class PositiveLabelClass:
@@ -116,7 +129,7 @@ class Metrics:
 
 class Transformers:
     """
-        Supported types of congito transformers names in autoai.
+    Supported types of congito transformers names in autoai.
     """
     SQRT = "sqrt"
     LOG = "log"
