@@ -50,7 +50,13 @@ __all__ = [
     'NotExistingCOSResource',
     'AdditionalParameterIsUnexpected',
     'OBMForNFSIsNotSupported',
-    'OBMMainNodeAlreadySet'
+    'ForecastPredictionColumnsMissing',
+    'NonForecastPredictionColumnMissing',
+    'ForecastingCannotBeRunAsLocalScenario',
+    'ForecastingUnsupportedOperation',
+    'OBMMainNodeAlreadySet',
+    'InvalidSequenceValue',
+    'NoAvailableMetrics'
 ]
 
 from ibm_watson_machine_learning.utils import WMLClientError
@@ -251,7 +257,38 @@ class OBMForNFSIsNotSupported(WMLClientError):
         WMLClientError.__init__(self, f"OBM for NFS is not supported.")
 
 
+class ForecastPredictionColumnsMissing(WMLClientError):
+    def __init__(self):
+        WMLClientError.__init__(self, "For prediction_type = `forecasting` passing `prediction_columns` is required, while `prediction_column` should be None.")
+
+
+class NonForecastPredictionColumnMissing(WMLClientError):
+    def __init__(self, prediction_type):
+        WMLClientError.__init__(self, f"For prediction_type = `{prediction_type}` passing `prediction_column` is required, while `prediction_columns` should be None.")
+
+
+class ForecastingCannotBeRunAsLocalScenario(WMLClientError):
+    def __init__(self):
+        WMLClientError.__init__(self, f"Forecasting cannot be run in local scenario.")
+
+
+class ForecastingUnsupportedOperation(WMLClientError):
+    def __init__(self):
+        WMLClientError.__init__(self, f"Operation is unsupported for timeseries forecasting prediction type.")
+
+
 class OBMMainNodeAlreadySet(WMLClientError):
     def __init__(self, param):
         WMLClientError.__init__(self, f"OBM Main node is already set to: {param}. If you want to set the new one,"
                                       f"please reinitialize entire object.")
+
+
+class InvalidSequenceValue(WMLClientError, ValueError):
+    def __init__(self, el, correct_values):
+        WMLClientError.__init__(self, f"Invalid sequence element: {el} sequence must be composed from"
+                                      f"given values: {correct_values}")
+
+
+class NoAvailableMetrics(WMLClientError):
+    def __init__(self):
+        WMLClientError.__init__(self, f"Currently there is no available metrics.")
