@@ -16,6 +16,7 @@ from typing import Union
 import sys
 
 from ibm_watson_machine_learning.utils.autoai.utils import try_import_tqdm
+
 try_import_tqdm()
 
 from tqdm import tqdm as TQDM
@@ -37,8 +38,12 @@ class ProgressBar(TQDM):
     total: int, optional
         Total length of the progress bar.
     """
-    def __init__(self, ncols: Union[str, int], position: int = 0, desc: str = None, total: int = 100, leave: bool = True) -> None:
-        super().__init__(desc=desc, total=total, leave=leave, position=position, ncols=ncols, file=sys.stdout)
+
+    def __init__(self, ncols: Union[str, int], position: int = 0, desc: str = None, total: int = 100,
+                 leave: bool = True, bar_format: str = '{desc}: {percentage:3.0f}%|{bar}|') -> None:
+        # note: to see possible progress bar formats please look at super 'bar_format' description
+        super().__init__(desc=desc, total=total, leave=leave, position=position, ncols=ncols, file=sys.stdout,
+                         bar_format=bar_format)
         self.total = total
         self.previous_message = None
         self.counter = 0
