@@ -42,20 +42,24 @@ __all__ = [
     'check_graphviz_binaries',
     'try_import_joblib',
     'get_sw_spec_and_type_based_on_sklearn',
-    'validate_additional_params_for_optimizer'
+    'validate_additional_params_for_optimizer',
+    'is_list_composed_from_enum'
 ]
 
 import io
 import json
 import os
+import enum
+import inspect
 from contextlib import redirect_stdout
 from functools import wraps
 from subprocess import check_call
 from sys import executable
 from tarfile import open as open_tar
-from typing import Dict, Union, Tuple, List, TYPE_CHECKING, Optional
+from typing import Dict, Union, Tuple, List, TYPE_CHECKING, Optional, Any
 from warnings import warn
 from zipfile import ZipFile
+from collections.abc import Sequence
 
 import pkg_resources
 import requests
@@ -63,7 +67,7 @@ from packaging import version
 
 from .errors import (MissingPipeline, DataFormatNotSupported, LibraryNotCompatible,
                      CannotInstallLibrary, CannotDownloadTrainingDetails, CannotDownloadWMLPipelineDetails,
-                     VisualizationFailed, AdditionalParameterIsUnexpected)
+                     VisualizationFailed, AdditionalParameterIsUnexpected, InvalidSequenceValue, NoAvailableMetrics)
 
 if TYPE_CHECKING:
     from io import BytesIO, BufferedIOBase
@@ -411,28 +415,32 @@ def preprocess_request_json(request_json: Dict, space_id: str) -> Dict:
     return request_json
 
 
-def chose_model_output(model_number: str) -> str:
+def chose_model_output(model_number: str, is_ml_metrics: bool = True, is_ts_metrics: bool = False) -> str:
     """Chose correct path for particular model number"""
-    model_number = int(model_number)
-    hpo_c_numbers = (4, 8, 12, 16)
-    cognito_numbers = (3, 7, 11, 15)
-    hpo_d_numbers = (2, 6, 10, 14)
-    pre_hpo_d_numbers = (1, 5, 9, 13)
+    if is_ml_metrics:
+        model_number = int(model_number)
+        hpo_c_numbers = (4, 8, 12, 16)
+        cognito_numbers = (3, 7, 11, 15)
+        hpo_d_numbers = (2, 6, 10, 14)
+        pre_hpo_d_numbers = (1, 5, 9, 13)
 
-    if model_number in pre_hpo_d_numbers:
-        return 'pre_hpo_d_output'
+        if model_number in pre_hpo_d_numbers:
+            return 'pre_hpo_d_output'
 
-    elif model_number in hpo_d_numbers:
-        return 'hpo_d_output'
+        elif model_number in hpo_d_numbers:
+            return 'hpo_d_output'
 
-    elif model_number in cognito_numbers:
-        return 'cognito_output'
+        elif model_number in cognito_numbers:
+            return 'cognito_output'
 
-    elif model_number in hpo_c_numbers:
-        return 'hpo_c_output'
+        elif model_number in hpo_c_numbers:
+            return 'hpo_c_output'
 
-    else:
-        return 'global_output'
+        else:
+            return 'global_output'
+
+    elif is_ts_metrics:
+        return 'after_pipeline_execution'
 
 
 def prepare_auto_ai_model_to_publish_notebook_normal_scenario(
@@ -609,7 +617,6 @@ def prepare_auto_ai_model_to_publish_normal_scenario(
     If cp4d: Dictionary with model schema and artifact name to upload, stored temporally in the user local file system.
     else: path name to the stored model in COS
     """
-
     request_json: Dict[str, dict] = download_request_json(run_params, pipeline_model, wml_client)
     # note: fill connection details
     request_json['content_location']['connection'] = run_params['entity']['results_reference']['connection']
@@ -791,7 +798,11 @@ class ProgressGenerator:
             "hpo_c_output": 70,
             "compose_model_type_output": 80,
             "fold_output": 90,
-            "global_output": 99
+            "global_output": 99,
+            # timeseries
+            'after_pipeline_execution': 50,
+            'after_holdout_execution': 80,
+            'after_final_pipelines_generation': 99
         }
         self.total = 100
         self.position = 0
@@ -834,16 +845,16 @@ def try_import_lale():
     """
     Check if lale package is installed in local environment, if not, just download and install it.
     """
-    lale_version = '0.4.12'
+    lale_version = '0.4.14'
     try:
         import lale
         from packaging import version
         if version.parse(lale.__version__) < version.parse(lale_version):
             warn(f"\"lale\" package version is to low."
-                 f"Installing version >={lale_version}")
+                 f"Installing version {lale_version}")
 
             try:
-                check_call([executable, "-m", "pip", "install", f"lale>={lale_version}"])
+                check_call([executable, "-m", "pip", "install", f"lale=={lale_version}"])
 
             except Exception as e:
                 raise CannotInstallLibrary(value_name=e,
@@ -851,10 +862,10 @@ def try_import_lale():
 
     except AttributeError:
         warn(f"Cannot determine \"lale\" package version."
-             f"Installing version >={lale_version}")
+             f"Installing version {lale_version}")
 
         try:
-            check_call([executable, "-m", "pip", "install", f"lale>={lale_version}"])
+            check_call([executable, "-m", "pip", "install", f"lale=={lale_version}"])
 
         except Exception as e:
             raise CannotInstallLibrary(value_name=e,
@@ -865,7 +876,7 @@ def try_import_lale():
              f"This is the needed dependency for pipeline model refinery, we will try to install it now...")
 
         try:
-            check_call([executable, "-m", "pip", "install", f"lale>={lale_version}"])
+            check_call([executable, "-m", "pip", "install", f"lale=={lale_version}"])
 
         except Exception as e:
             raise CannotInstallLibrary(value_name=e,
@@ -1142,54 +1153,130 @@ def create_summary(details: dict, scoring: str) -> 'DataFrame':
     """
     from pandas import DataFrame
 
-    columns = (['Pipeline Name', 'Number of enhancements', 'Estimator'] +
+    is_ml_metrics = 'ml_metrics' in details['entity']['status'].get('metrics', [{}])[0]
+    is_ts_metrics = 'ts_metrics' in details['entity']['status'].get('metrics', [{}])[0]
+
+    if not is_ml_metrics and not is_ts_metrics:
+        raise NoAvailableMetrics()
+
+    def get_metrics_names():
+        if is_ml_metrics:
+            return details['entity']['status'].get('metrics', [{}])[0].get('ml_metrics', {}).keys()
+        elif is_ts_metrics:
+            names = list(['validation_' + x for x in details['entity']['status'].get('metrics', [{}])[0].get('ts_metrics', {}).get('training',{}).keys()])
+            holdout_names = list(['holdout_' + y for y in [x for x in details['entity']['status'].get('metrics', [{}]) if 'holdout' in x['ts_metrics']][0]['ts_metrics']['holdout'].keys()])
+            backtest_names = list(['backtest_' + y for y in [x for x in details['entity']['status'].get('metrics', [{}]) if 'backtest' in x['ts_metrics']][0]['ts_metrics']['backtest']['avg'].keys()])
+
+            return names + holdout_names + backtest_names
+
+    def is_winner(pipeline_name): # ts only
+        if is_ts_metrics:
+            return len(list([x for x in details['entity']['status'].get('metrics', [{}])
+                  if x['context']['intermediate_model']['name'] == pipeline_name and 'holdout' in x['ts_metrics']])) > 0
+        elif is_ml_metrics:
+            return True
+
+    if is_ml_metrics:
+        columns = ['Pipeline Name', 'Enhancements', 'Estimator']
+    elif is_ts_metrics:
+        columns = ['Pipeline Name', 'Enhancements', 'Estimator', 'Winner']
+
+    columns = (columns +
                [metric_name for metric_name in
-                details['entity']['status'].get('metrics', [{}])[0].get('ml_metrics', {}).keys()])
+                get_metrics_names()])
     values = []
 
     for pipeline in details['entity']['status'].get('metrics', []):
         model_number = pipeline['context']['intermediate_model']['name'].split('P')[-1]
-        model_phase = chose_model_output(model_number)
+        model_phase = chose_model_output(model_number, is_ml_metrics, is_ts_metrics)
 
         if pipeline['context']['phase'] == model_phase:
-            number_of_enhancements = len(pipeline['context']['intermediate_model']['composition_steps']) - 5
+            if is_ml_metrics:
+                enhancements = ', '.join(pipeline['context']['intermediate_model']['composition_steps'])
+            elif is_ts_metrics:
+                enhancements = 'HPO, FE'
+
+            def get_metrics_items():
+                if is_ml_metrics:
+                    return pipeline['ml_metrics'].items()
+                elif is_ts_metrics:
+                    def prepare_items(metrics, pipeline_name, metric_name, prefix):
+                        try:
+                            chosen_obj = [x for x in metrics if x['context']['intermediate_model']['name'] == pipeline_name and metric_name in x['ts_metrics']][0]
+                        except Exception as e:
+                            return []
+
+                        if metric_name == 'backtest':
+                            return list({prefix + x: chosen_obj['ts_metrics'][metric_name]['avg'][x] for x in chosen_obj['ts_metrics'][metric_name]['avg']}.items())
+                        else:
+                            return list({prefix + x: chosen_obj['ts_metrics'][metric_name][x] for x in chosen_obj['ts_metrics'][metric_name]}.items())
+
+                    pipeline_name = pipeline['context']['intermediate_model']['name']
+                    metrics = details['entity']['status'].get('metrics', [])
+                    training_items = prepare_items(metrics, pipeline_name, 'training', 'validation_')
+                    holdout_items = prepare_items(metrics, pipeline_name, 'holdout', 'holdout_')
+                    backtest_items = prepare_items(metrics, pipeline_name, 'backtest', 'backtest_')
+
+                    return training_items + holdout_items + backtest_items
 
             # note: workaround when some pipelines have less or more metrics computed
-            metrics = columns[3:]
+            if is_ml_metrics:
+                metrics = columns[3:]
+            elif is_ts_metrics:
+                metrics = columns[4:]
             pipeline_metrics = [None] * len(metrics)
-            for metric, value in pipeline['ml_metrics'].items():
+            for metric, value in get_metrics_items():
                 for i, metric_name in enumerate(metrics):
                     if metric_name == metric:
                         pipeline_metrics[i] = value
             # --- end note
 
-            values.append(
-                ([f"Pipeline_{pipeline['context']['intermediate_model']['name'].split('P')[-1]}"] +
-                 [number_of_enhancements] +
-                 [pipeline['context']['intermediate_model']['pipeline_nodes'][-1]] +
-                 pipeline_metrics
-                 ))
+            if is_ml_metrics:
+                values.append(
+                    ([f"Pipeline_{pipeline['context']['intermediate_model']['name'].split('P')[-1]}"] +
+                     [enhancements] +
+                     [pipeline['context']['intermediate_model']['pipeline_nodes'][-1]] +
+                     pipeline_metrics
+                     ))
+            elif is_ts_metrics:
+                values.append(
+                    ([f"Pipeline_{pipeline['context']['intermediate_model']['name'].split('P')[-1]}"] +
+                     [enhancements] +
+                     [pipeline['context']['intermediate_model']['pipeline_nodes'][-1]] +
+                     [is_winner(pipeline['context']['intermediate_model']['name'])] +
+                     pipeline_metrics
+                     ))
 
     pipelines = DataFrame(data=values, columns=columns)
     pipelines.drop_duplicates(subset="Pipeline Name", keep='first', inplace=True)
     pipelines.set_index('Pipeline Name', inplace=True)
 
     try:
-        pipelines = pipelines.sort_values(
-            by=[f"training_{scoring}"], ascending=False).rename(
-            {
-                f"training_{scoring}":
-                    f"training_{scoring}_(optimized)"
-            }, axis='columns')
+        if is_ml_metrics:
+            pipelines = pipelines.sort_values(
+                by=[f"training_{scoring}"], ascending=False).rename(
+                {
+                    f"training_{scoring}":
+                        f"training_{scoring}_(optimized)"
+                }, axis='columns')
+        elif is_ts_metrics:
+            pipelines = pipelines.sort_values(
+                by=['Winner'] + get_metrics_names(), ascending=False)
 
     # note: sometimes backend will not return 'training_' prefix to the metric
     except KeyError:
         pass
 
+    # for columns with _neg_ inside name
     neg_columns = [col for col in pipelines if '_neg_' in col]
-    pipelines[neg_columns] = -pipelines[neg_columns]
+    pipelines[neg_columns] = pipelines[neg_columns].apply(lambda x: -x if x is not None else x)
     pipelines = pipelines.rename(columns={col: col.replace('_neg_', '_') for col in neg_columns})
 
+    # for columns with neg_ on beginning of name
+    neg_columns = [col for col in pipelines if col.startswith('neg_')]
+    pipelines[neg_columns] = pipelines[neg_columns].apply(lambda x: -x if x is not None else x)
+    pipelines = pipelines.rename(columns={col: col[4:] for col in neg_columns})
+
     return pipelines
 
 
@@ -1297,20 +1384,20 @@ def get_sw_spec_and_type_based_on_sklearn(client: 'APIClient', spec: str) -> Tup
     """
     import sklearn
 
-    if '0.20.' in sklearn.__version__ and 'autoai-kb_3.0-py3.6' == spec:
+    if '0.20.' in sklearn.__version__ and spec in ['autoai-kb_3.0-py3.6', 'autoai-ts_1.0-py3.6']:
         sw_spec = client.software_specifications.get_id_by_name('autoai-kb_3.0-py3.6')
         model_type = 'scikit-learn_0.20'
 
-    elif '0.20.' in sklearn.__version__ and 'autoai-kb_3.0-py3.6' != spec:
+    elif '0.20.' in sklearn.__version__ and spec not in ['autoai-kb_3.0-py3.6', 'autoai-ts_1.0-py3.6']:
         raise LibraryNotCompatible(reason="Your version of scikit-learn is different then trained pipeline. "
                                           "Trained pipeline version: 0.23.* "
                                           "Your version: " + sklearn.__version__)
 
-    elif '0.23.' in sklearn.__version__ and 'autoai-kb_3.1-py3.7' == spec:
+    elif '0.23.' in sklearn.__version__ and spec in ['autoai-kb_3.1-py3.7', 'autoai-ts_1.0-py3.7']:
         sw_spec = client.software_specifications.get_id_by_name('autoai-kb_3.1-py3.7')
         model_type = 'scikit-learn_0.23'
 
-    elif '0.23.' in sklearn.__version__ and 'autoai-kb_3.1-py3.7' != spec:
+    elif '0.23.' in sklearn.__version__ and spec not in ['autoai-kb_3.1-py3.7', 'autoai-ts_1.0-py3.7']:
         raise LibraryNotCompatible(reason="Your version of scikit-learn is different then trained pipeline. "
                                           "Trained pipeline version: 0.20.* "
                                           "Your version: " + sklearn.__version__)
@@ -1346,7 +1433,8 @@ def validate_additional_params_for_optimizer(params):
         'FE_drop_constant_columns_flag', 'FE_add_frequency_columns_flag', 'FE_add_missing_indicator_columns_flag',
         'data_provenance', 'target_label_name', 'preprocessor_data_filename', 'cognito_data_filename',
         'holdout_roc_curve_max_size', 'holdout_reg_pred_obs_max_size', 'max_estimator_n_jobs',
-        'enabled_feature_engineering_as_json', 'fairness_info']
+        'enabled_feature_engineering_as_json', 'fairness_info', 'prediction_columns', 'timestamp_column_name',
+        'backtest_num', 'forecast_window', 'lookback_window', 'backtest_gap_length']
 
     for k in params:
         if k not in expected_params:
@@ -1355,10 +1443,21 @@ def validate_additional_params_for_optimizer(params):
 
 def download_request_json(run_params: dict, model_name: str, wml_client) -> dict:
     run_id = run_params['metadata']['id']
+    is_ml_metrics = 'ml_metrics' in run_params['entity']['status'].get('metrics')[-1]
+    is_ts_metrics = 'ts_metrics' in run_params['entity']['status'].get('metrics')[-1]
+
+    if not is_ml_metrics and not is_ts_metrics:
+        raise NoAvailableMetrics()
+
     pipeline_info = run_params['entity']['status'].get('metrics')[-1]
     schema_path = f"{pipeline_info['context']['intermediate_model']['schema_location']}"
-    model_number = model_name.split('_')[-1]
-    request_path = f"{schema_path.split('/data/')[0]}/assets/{run_id}_P{model_number}_{chose_model_output(model_number)}/resources/wml_model/request.json"
+    if is_ml_metrics:
+        model_number = model_name.split('_')[-1]
+        model_output = chose_model_output(model_number)
+    elif is_ts_metrics:
+        model_number = pipeline_info['context']['intermediate_model']['name'][1:]
+        model_output = 'after_final_pipelines_generation'
+    request_path = f"{schema_path.split('/data/')[0]}/assets/{run_id}_P{model_number}_{model_output}/resources/wml_model/request.json"
 
     if wml_client.ICP:
         request_str = load_file_from_file_system(wml_client=wml_client, file_path=request_path).read().decode()
@@ -1386,3 +1485,35 @@ def download_request_json(run_params: dict, model_name: str, wml_client) -> dict
     return request_json
 
 
+def is_list_composed_from_enum(sequence: List[Union[str, enum.Enum]],
+                               enum_class: Union[object, enum.EnumMeta]
+                               ) -> None:
+    """
+    Check if all the elements of a given sequence are values of a given enum class.
+
+    Parameters
+    ----------
+    sequence: List[Union[str, enum.Enum]
+        Sequence of elements.
+    enum_class: Union[object, enum.Enum, List[enum.Enum]
+        Class for which validation will be performed.
+        It can be a class inheriting from enum.Enum or class with defined only defined class
+        attributes.
+
+    Raises
+    -------
+    InvalidSequenceValue, If element is not from enum class values.
+    """
+    if sequence is not None:
+        if isinstance(enum_class, enum.EnumMeta):
+            enum_values = [e.value for e in enum_class]
+        else:
+            attributes = inspect.getmembers(enum_class, lambda attr: not (inspect.isroutine(attr)))
+            enum_values = [attr_val for attr_name, attr_val in attributes
+                           if not(attr_name.startswith('__') and attr_name.endswith('__'))]
+
+        print(enum_values)
+        for el in sequence:
+            el_value = el.value if isinstance(el, enum.Enum) else el
+            if el_value not in enum_values:
+                raise InvalidSequenceValue(el, enum_values)
