@@ -1,3 +1,17 @@
+# (C) Copyright IBM Corp. 2020.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 __all__ = [
     "WrongDeploymnetType",
     "ModelTypeNotSupported",
@@ -6,7 +20,8 @@ __all__ = [
     'BatchJobFailed',
     'MissingScoringResults',
     'ModelStoringFailed',
-    'DeploymentNotSupported'
+    'DeploymentNotSupported',
+    'MissingSpace'
 ]
 
 from ibm_watson_machine_learning.utils import WMLClientError
@@ -50,3 +65,8 @@ class ModelStoringFailed(WMLClientError, ValueError):
 class DeploymentNotSupported(WMLClientError, ValueError):
     def __init__(self, value_name=None, reason=None):
         WMLClientError.__init__(self, f"Deployment of type: {value_name} is not supported.", reason)
+
+
+class MissingSpace(WMLClientError, ValueError):
+    def __init__(self, value_name=None, reason=None):
+        WMLClientError.__init__(self, f"Deployment needs to have space specified", reason)
