@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from ibm_watson_machine_learning.utils.log_util import get_logger
+import logging
 import sys
 
 __all__ = [
@@ -34,8 +34,8 @@ class WMLClientError(Exception):
     def __init__(self, error_msg, reason = None):
         self.error_msg = error_msg
         self.reason = reason
-        get_logger(__name__).warning(self.__str__())
-        get_logger(__name__).debug(str(self.error_msg) + ('\nReason: ' + str(self.reason) if sys.exc_info()[0] is not None else ''))
+        logging.getLogger(__name__).warning(self.__str__())
+        logging.getLogger(__name__).debug(str(self.error_msg) + ('\nReason: ' + str(self.reason) if sys.exc_info()[0] is not None else ''))
 
     def __str__(self):
         return str(self.error_msg) + ('\nReason: ' + str(self.reason) if self.reason is not None else '')
